## Overview

Scrapyd ScrapyArt

Scrapyd: scrapyd can manage multiple projects and each project can have multiple versions uploaded, but only the latest one will be used for launching new spiders. A common (and useful) convention to use for the version name is the revision number of the version control tool you’re using to track your Scrapy project code. For example: r23. The versions are not compared alphabetically but using a smarter algorithm (the same distutils uses) so r10 compares greater to r9, for example.

scrapyd document click here

ScrapydArt: it is modified by author Quinn based on scrapyd, retaining all the original functions of scrapyd, and adding permission validation, reconstructing HTML layout, other functional api, etc. see Feature for more details

scrapyd document click here